@@ -17,6 +17,7 @@
 from distutils import version
 import functools
 import logging
+import re
 import string
 import threading
 
@@ -102,10 +103,10 @@ class RedisLock(locking.Lock):
         return bool(self._client.delete(self.name))
 
     @_handle_failures()
-    def acquire(self, blocking=True, shared=False):
+    def acquire(self, blocking=True, shared=False, timeout=None):
         if shared:
             raise tooz.NotImplemented
-        blocking, timeout = utils.convert_blocking(blocking)
+        blocking, timeout = utils.convert_blocking(blocking, timeout)
         acquired = self._lock.acquire(
             blocking=blocking, blocking_timeout=timeout)
         if acquired:
@@ -159,7 +160,8 @@ class RedisDriver(coordination.CoordinationDriverCachedRunWatchers,
 
     The Redis driver connection URI should look like::
 
-      redis://[:PASSWORD@]HOST:PORT[?OPTION=VALUE[&OPTION2=VALUE2[&...]]]
+      redis://[USERNAME:PASSWORD@]HOST:PORT
+          [?OPTION=VALUE[&OPTION2=VALUE2[&...]]]
 
     For a list of options recognized by this driver, see the documentation
     for the member CLIENT_ARGS, and to determine the expected types of those
@@ -258,9 +260,11 @@ class RedisDriver(coordination.CoordinationDriverCachedRunWatchers,
         'socket_keepalive',
         'socket_timeout',
         'socket_connect_timeout',
+        'health_check_interval',
         'ssl',
         'ssl_certfile',
         'ssl_keyfile',
+        'ssl_ca_certs',
         'sentinel',
         'sentinel_fallback',
     ])
@@ -282,19 +286,20 @@ class RedisDriver(coordination.CoordinationDriverCachedRunWatchers,
     #: Client arguments that are expected to be boolean convertible.
     CLIENT_BOOL_ARGS = frozenset([
         'retry_on_timeout',
+        'socket_keepalive',
         'ssl',
     ])
 
     #: Client arguments that are expected to be int convertible.
     CLIENT_INT_ARGS = frozenset([
         'db',
-        'socket_keepalive',
     ])
 
     #: Client arguments that are expected to be float convertible.
     CLIENT_FLOAT_ARGS = frozenset([
         'socket_timeout',
         'socket_connect_timeout',
+        'health_check_interval',
     ])
 
     #: Default socket timeout to use when none is provided.
@@ -416,6 +421,18 @@ return 1
     _dumps = staticmethod(utils.dumps)
     _loads = staticmethod(utils.loads)
 
+    @classmethod
+    def _parse_sentinel(cls, sentinel):
+        # IPv6 (eg. [::1]:6379 )
+        match = re.search(r'^\[(\S+)\]:(\d+)$', sentinel)
+        if match:
+            return (match[1], int(match[2]))
+        # IPv4 or hostname (eg. 127.0.0.1:6379 or localhost:6379)
+        match = re.search(r'^(\S+):(\d+)$', sentinel)
+        if match:
+            return (match[1], int(match[2]))
+        raise ValueError('Malformed sentinel server format')
+
     @classmethod
     def _make_client(cls, parsed_url, options, default_socket_timeout):
         kwargs = {}
@@ -427,6 +444,8 @@ return 1
             if not parsed_url.path:
                 raise ValueError("Expected socket path in parsed urls path")
             kwargs['unix_socket_path'] = parsed_url.path
+        if parsed_url.username:
+            kwargs['username'] = parsed_url.username
         if parsed_url.password:
             kwargs['password'] = parsed_url.password
         for a in cls.CLIENT_ARGS:
@@ -450,18 +469,16 @@ return 1
         # sentinel arg.
         if 'sentinel' in kwargs:
             sentinel_hosts = [
-                tuple(fallback.split(':'))
-                for fallback in kwargs.get('sentinel_fallback', [])
+                cls._parse_sentinel(fallback)
+                for fallback in kwargs.pop('sentinel_fallback', [])
             ]
             sentinel_hosts.insert(0, (kwargs['host'], kwargs['port']))
+            sentinel_name = kwargs.pop('sentinel')
             sentinel_server = sentinel.Sentinel(
                 sentinel_hosts,
-                socket_timeout=kwargs['socket_timeout'])
-            sentinel_name = kwargs['sentinel']
-            del kwargs['sentinel']
-            if 'sentinel_fallback' in kwargs:
-                del kwargs['sentinel_fallback']
-            master_client = sentinel_server.master_for(sentinel_name, **kwargs)
+                sentinel_kwargs=kwargs,
+                **kwargs)
+            master_client = sentinel_server.master_for(sentinel_name)
             # The master_client is a redis.Redis using a
             # Sentinel managed connection pool.
             return master_client
